ConsistentHash

Struct ConsistentHash 

pub struct ConsistentHash<Stub, S = RandomState> { /* private fields */ }
A Stub that load-balances across backing stubs by round robin.

Implementations

Source

impl<Stub> ConsistentHash<Stub, RandomState>
where Stub: Stub, Stub::Req: Hash,

pub fn new(stubs: Vec<Stub>) -> Result<Self, TryFromIntError>

Returns a new RoundRobin stub. Returns an err if the length of stubs overflows a u64.

Source

impl<Stub, S> ConsistentHash<Stub, S>
where Stub: Stub, Stub::Req: Hash, S: BuildHasher,

pub fn with_hasher(stubs: Vec<Stub>, hasher: S) -> Result<Self, TryFromIntError>

Returns a new RoundRobin stub. Returns an err if the length of stubs overflows a u64.