pub struct ConsistentHash<Stub, S = RandomState> { /* private fields */ }Expand description
A Stub that load-balances across backing stubs by round robin.
Implementations
Sourceimpl<Stub> ConsistentHash<Stub, RandomState>
impl<Stub> ConsistentHash<Stub, RandomState>
Sourcepub fn new(stubs: Vec<Stub>) -> Result<Self, TryFromIntError>
pub fn new(stubs: Vec<Stub>) -> Result<Self, TryFromIntError>
Returns a new RoundRobin stub.
Returns an err if the length of stubs overflows a u64.
Sourceimpl<Stub, S> ConsistentHash<Stub, S>
impl<Stub, S> ConsistentHash<Stub, S>
Sourcepub fn with_hasher(stubs: Vec<Stub>, hasher: S) -> Result<Self, TryFromIntError>
pub fn with_hasher(stubs: Vec<Stub>, hasher: S) -> Result<Self, TryFromIntError>
Returns a new RoundRobin stub.
Returns an err if the length of stubs overflows a u64.